# KnifeSwap release 1 by David Bowland
# ./addons/eventscripts/knifeswap/knifeswap.py

# >>> To configure this addon please see knifeswap.cfg <<<

"""
Provides a client command to swap between the knife and last active weapon. Requires only ES 2.0+
"""


import es
import gamethread
import langlib
import os.path
import playerlib

import psyco
psyco.full()


info = es.AddonInfo()
info.name     = 'KnifeSwap'
info.version  = '1'
info.url      = 'http://addons.eventscripts.com/addons/view/knifeswap'
info.basename = 'knifeswap'
info.author   = 'SuperDave'


###


def getLangFunc():
   lang_path = es.getAddonPath('knifeswap') + '/knifeswap_languages.ini'
   if os.path.isfile(lang_path):
      return langlib.Strings(lang_path)
   else:
      es.dbgmsg(0, 'KnifeSwap: Unable to load cheapwirecut_languages.ini! Please ensure it is in the ./cheapwirecut/ directory.')
   return lambda x, y, z: 'KnifeSwap: knifeswap_languages.ini not found'

func_lang_text = getLangFunc()


###


dict_options = {'knifeswap_announce_chat':[2, '0 = no change, 1 = announce knife swap command on the console at the beginning of the round, 2 = announce knife swap command in chat area at the beginning of the round'], 'knifeswap_announce_hud':[1, '0 = no change, 1 = announce knife swap command in a HUD hint at the beginning of the round']}


def load():
   """
   Ensures critical server variables are created by the config
   """
   for str_option in dict_options:
      es.ServerVar(str_option, dict_options[str_option][0], dict_options[str_option][1])
   if os.path.isfile(es.getAddonPath('knifeswap') + '/knifeswap.cfg'):
      es.server.cmd('es_xmexec ../addons/eventscripts/knifeswap/knifeswap.cfg')
   else:
      es.dbgmsg(0, 'KnifeSwap: Unable to load knifeswap.cfg! Please ensure it is in the ./knifeswap/ directory.')


def round_start(event_var):
   chat = int(es.ServerVar('knifeswap_announce_chat'))
   hud  = int(es.ServerVar('knifeswap_announce_hud'))
   if not chat and not hud: return

   for userid in filter(lambda x: not es.getplayerprop(x, 'CBasePlayer.pl.deadflag'), es.getUseridList()):
      lang = playerlib.getPlayer(userid).get('lang')

      if chat:
         if chat == 1:
            es.cexec(userid, 'echo ' + remove_tags(func_lang_text('command announce', {}, lang)))
         else:
            es.tell(userid, '#multi', func_lang_text('command announce', {}, lang))

      if hud:
         hud_hint(userid, remove_tags(func_lang_text('command announce', {}, lang)))


def unload():
   es.unregclientcmd('knifeswap')

   for str_option in dict_options:
      es.ServerVar(str_option).set(0)


###


def swap_cmd():
   userid = es.getcmduserid()

   if es.createplayerlist(userid)[userid]['weapon'] == 'weapon_knife':
      es.cexec(userid, 'lastinv')

   else:
      es.sexec(userid, 'use weapon_knife')

if not es.exists('clientcommand', 'knifeswap'):
   es.regclientcmd('knifeswap', 'knifeswap/swap_cmd', 'Command to swap between the knife and last active weapon')


###


def hud_hint(userid, message):
   """Sends the player a HUD hint"""
   es.usermsg('create', 'knifeswap_hud', 'HintText')
   es.usermsg('write', 'short', 'knifeswap_hud', -1)
   es.usermsg('write', 'string', 'knifeswap_hud', message)
   es.usermsg('send', 'knifeswap_hud', userid)
   es.usermsg('delete', 'knifeswap_hud')


def remove_tags(text):
   """Removes #lightgreen, #green and #default tags from the supplied string"""
   return text.replace('#lightgreen', '').replace('#green', '').replace('#default', '')